{% extends "base.html" %}
{% block main_content %}
<div class="col-12 col-md-8">
  <p class="text-center display-3 text-primary"><i class="bi bi-cloud-sleet"></i></p>
  <p class="text-center display-4">この記事はsません</p>
      <p>この記事は存在しません。これは次のいずれかが原因である可能性があります。</p>
      
      <ul>
          <li>Urlが間違っている</li>
          <li>この記事はすでに削除されている</li>
        </ul>
      </div>
  {% endblock %}